@@ -82,13 +82,13 @@ ImageThumbnailBar::ImageThumbnailBar(QWidget* const parent)
     setSpacing(3);
     setUsePointingHandCursor(false);
     setScrollStepGranularity(5);
-    setScrollCurrentToCenter(true);
     setScrollBarPolicy(Qt::ScrollBarAlwaysOn);
 
     setDragEnabled(true);
     setAcceptDrops(true);
     setDropIndicatorShown(false);
 
+    setScrollCurrentToCenter(ApplicationSettings::instance()->getScrollItemToCenter());
     setToolTipEnabled(ApplicationSettings::instance()->showToolTipsIsValid());
 
     connect(ApplicationSettings::instance(), SIGNAL(setupChanged()),
@@ -193,6 +193,7 @@ void ImageThumbnailBar::setFlow(QListView::Flow flow)
 
 void ImageThumbnailBar::slotSetupChanged()
 {
+    setScrollCurrentToCenter(ApplicationSettings::instance()->getScrollItemToCenter());
     setToolTipEnabled(ApplicationSettings::instance()->showToolTipsIsValid());
     setFont(ApplicationSettings::instance()->getIconViewFont());
 
