@@ -73,6 +73,7 @@ public:
     static const QString                      configIconShowCommentsEntry;
     static const QString                      configIconShowTagsEntry;
     static const QString                      configIconShowOverlaysEntry;
+    static const QString                      configIconShowFullscreenEntry;
     static const QString                      configIconShowRatingEntry;
     static const QString                      configIconShowImageFormatEntry;
     static const QString                      configIconShowCoordinatesEntry;
@@ -123,6 +124,7 @@ public:
     static const QString                      configShowTrashDeleteDialogEntry;
     static const QString                      configShowPermanentDeleteDialogEntry;
     static const QString                      configApplySidebarChangesDirectlyEntry;
+    static const QString                      configScrollItemToCenterEntry;
     static const QString                      configScanAtStartEntry;
     static const QString                      configSyncBalootoDigikamEntry;
     static const QString                      configSyncDigikamtoBalooEntry;
@@ -138,6 +140,8 @@ public:
     bool                                      showPermanentDeleteDialog;
     // metadata setting
     bool                                      sidebarApplyDirectly;
+    // item center settings
+    bool                                      scrollItemToCenter;
 
     // icon view settings
     bool                                      iconShowName;
@@ -149,6 +153,7 @@ public:
     bool                                      iconShowResolution;
     bool                                      iconShowTags;
     bool                                      iconShowOverlays;
+    bool                                      iconShowFullscreen;
     bool                                      iconShowRating;
     bool                                      iconShowImageFormat;
     bool                                      iconShowCoordinates;
