@@ -180,6 +180,9 @@ StackedView::StackedView(QWidget* const parent)
     connect(d->imagePreviewView, SIGNAL(signalSlideShow()),
             this, SIGNAL(signalSlideShow()));
 
+    connect(d->imagePreviewView, SIGNAL(signalSlideShowCurrent()),
+            this, SIGNAL(signalSlideShowCurrent()));
+
     connect(d->imagePreviewView->layout(), SIGNAL(zoomFactorChanged(double)),
             this, SLOT(slotZoomFactorChanged(double)));
 
