@@ -213,13 +213,10 @@ RedEyeTool::RedEyeTool(QObject* const parent)
     setToolSettings(d->gboxSettings);
 
     // -------------------------------------------------------------
-
+/*
     connect(d->previewWidget, SIGNAL(spotPositionChangedFromTarget(Digikam::DColor,QPoint)),
             this, SLOT(slotColorSelectedFromTarget(Digikam::DColor)));
-
-    connect(d->previewWidget, SIGNAL(signalResized()),
-            this, SLOT(slotPreview()));
-
+*/
     connect(d->redThreshold, SIGNAL(valueChanged(int)),
             this, SLOT(slotTimer()));
 
@@ -493,8 +490,8 @@ void RedEyeTool::redEyeFilter(DImg& selection)
     }
     else                                 // 16 bits image.
     {
-        unsigned short* ptr  = (unsigned short*)selection.bits();
-        unsigned short* mptr = (unsigned short*)mask.bits();
+        unsigned short* ptr  = reinterpret_cast<unsigned short*>(selection.bits());
+        unsigned short* mptr = reinterpret_cast<unsigned short*>(mask.bits());
         unsigned short  r, g, b, r1, g1, b1;
 
         for (uint i = 0 ; i < selection.width() * selection.height() ; ++i)
@@ -557,8 +554,8 @@ void RedEyeTool::redEyeFilter(DImg& selection)
     }
     else                                // 16 bits image.
     {
-        unsigned short* mptr  = (unsigned short*)mask.bits();
-        unsigned short* mptr2 = (unsigned short*)mask2.bits();
+        unsigned short* mptr  = reinterpret_cast<unsigned short*>(mask.bits());
+        unsigned short* mptr2 = reinterpret_cast<unsigned short*>(mask2.bits());
 
         for (uint i = 0 ; i < mask2.width() * mask2.height() ; ++i)
         {
