@@ -7,7 +7,7 @@
  * Description : database thumbnail interface.
  *
  * Copyright (C)      2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2015 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -255,9 +255,9 @@ DatabaseCoreBackend::QueryState ThumbnailDB::insertThumbnail(const DatabaseThumb
 {
     QVariant id;
     DatabaseCoreBackend::QueryState lastQueryState;
-    lastQueryState= d->db->execSql("INSERT INTO Thumbnails (type, modificationDate, orientationHint, data) VALUES (?, ?, ?, ?);",
-                                   info.type, info.modificationDate, info.orientationHint, info.data,
-                                   0, &id);
+    lastQueryState = d->db->execSql("INSERT INTO Thumbnails (type, modificationDate, orientationHint, data) VALUES (?, ?, ?, ?);",
+                                    info.type, info.modificationDate, info.orientationHint, info.data,
+                                    0, &id);
 
     if (DatabaseCoreBackend::NoErrors==lastQueryState)
     {
@@ -279,7 +279,7 @@ DatabaseCoreBackend::QueryState ThumbnailDB::replaceThumbnail(const DatabaseThum
 
 DatabaseCoreBackend::QueryState ThumbnailDB::updateModificationDate(int thumbId, const QDateTime& modificationDate)
 {
-    return d->db->execSql("UPDATE Thumbnails SET modificationDate=? WHERE id=?;", thumbId, modificationDate);
+    return d->db->execSql("UPDATE Thumbnails SET modificationDate=? WHERE id=?;", modificationDate, thumbId);
 }
 
 void ThumbnailDB::replaceUniqueHash(const QString& oldUniqueHash, int oldFileSize,
