@@ -12,7 +12,7 @@
  *               http://community.kde.org/Digikam/SoK2012/AutoNR
  *
  * Copyright (C) 2012-2013 by Sayantan Datta <sayantan dot knz at gmail dot com>
- * Copyright (C) 2012-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012-2015 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -77,7 +77,8 @@ public:
 };
 
 NREstimate::NREstimate(DImg* const img, QObject* const parent)
-    : DImgThreadedAnalyser(parent, "NREstimate"), d(new Private)
+    : DImgThreadedAnalyser(parent, "NREstimate"),
+      d(new Private)
 {
     // Use the Top/Left corner of 256x256 pixels to analys noise contents from image.
     // This will speed-up computation time with OpenCV
@@ -241,11 +242,6 @@ void NREstimate::startAnalyse()
 
     float* ptr = 0;
 
-    if (runningFlag())
-    {
-        ptr = reinterpret_cast<float*>(sd->data.ptr);
-    }
-
     kDebug() << "The rowPosition array is ready!";
     postProgress(40);
 
@@ -461,11 +457,9 @@ void NREstimate::startAnalyse()
 
         if (datasd[0] < 7)
             L = datasd[0] - 0.98;
-
-        if (datasd[0] >= 7 && datasd[0] < 8)
+        else if (datasd[0] >= 7 && datasd[0] < 8)
             L = datasd[0] - 1.2;
-
-        if (datasd[0] >= 8 && datasd[0] < 9)
+        else if (datasd[0] >= 8 && datasd[0] < 9)
             L = datasd[0] - 1.5;
         else
             L = datasd[0] - 1.7;
@@ -491,10 +485,8 @@ void NREstimate::startAnalyse()
 
         if ( L > 9 )
             LSoft = CrSoft = CbSoft = 0.8;
-
         else if ( L > 3)
             LSoft = CrSoft = CbSoft = 0.7;
-
         else
             LSoft = CrSoft = CbSoft = 0.6;
     }
