@@ -6,7 +6,7 @@
  * Date        : 2007-08-02
  * Description : save JPEG image options.
  *
- * Copyright (C) 2007-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -35,22 +35,20 @@
 namespace Digikam
 {
 
-class JPEGSettingsPriv;
-
 class DIGIKAM_EXPORT JPEGSettings : public QWidget
 {
     Q_OBJECT
 
 public:
 
-    JPEGSettings(QWidget* parent = 0);
+    explicit JPEGSettings(QWidget* const parent = 0);
     ~JPEGSettings();
 
     void setCompressionValue(int val);
-    int  getCompressionValue();
+    int  getCompressionValue() const;
 
     void setSubSamplingValue(int val);
-    int  getSubSamplingValue();
+    int  getSubSamplingValue() const;
 
     static int convertCompressionForLibJpeg(int value);
 
@@ -60,7 +58,8 @@ Q_SIGNALS:
 
 private:
 
-    JPEGSettingsPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 }  // namespace Digikam
