@@ -6,7 +6,7 @@
  * Date        : 2010-08-20
  * Description : Metadata Settings Container.
  *
- * Copyright (C) 2010-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2014 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,11 +44,13 @@ MetadataSettingsContainer::MetadataSettingsContainer()
     saveColorLabel        = false;
     saveRating            = false;
     saveTemplate          = false;
+    saveFaceTags          = false;
     saveTags              = false;
     writeRawFiles         = false;
     useXMPSidecar4Reading = false;
     metadataWritingMode   = KExiv2::WRITETOIMAGEONLY;
-    updateFileTimeStamp   = false;
+    updateFileTimeStamp   = true;
+    rescanImageIfModified = false;
     rotationBehavior      = RotatingFlags | RotateByLosslessRotation;
 }
 
@@ -59,6 +61,7 @@ void MetadataSettingsContainer::readFromConfig(KConfigGroup& group)
 
     saveTags              = group.readEntry("Save Tags",                   false);
     saveTemplate          = group.readEntry("Save Template",               false);
+    saveFaceTags          = group.readEntry("Save FaceTags",               false);
 
     saveComments          = group.readEntry("Save EXIF Comments",          false);
     saveDateTime          = group.readEntry("Save Date Time",              false);
@@ -68,9 +71,10 @@ void MetadataSettingsContainer::readFromConfig(KConfigGroup& group)
 
     writeRawFiles         = group.readEntry("Write RAW Files",             false);
     useXMPSidecar4Reading = group.readEntry("Use XMP Sidecar For Reading", false);
-    metadataWritingMode   = (KExiv2::MetadataWritingMode)group.readEntry("Metadata Writing Mode",
-                                                                           (int)KExiv2::WRITETOIMAGEONLY);
-    updateFileTimeStamp   = group.readEntry("Update File Timestamp",       false);
+    metadataWritingMode   = (KExiv2::MetadataWritingMode)
+                            group.readEntry("Metadata Writing Mode",       (int)KExiv2::WRITETOIMAGEONLY);
+    updateFileTimeStamp   = group.readEntry("Update File Timestamp",       true);
+    rescanImageIfModified = group.readEntry("Rescan File If Modified",     false);
 
     rotationBehavior      = NoRotation;
 
@@ -78,14 +82,17 @@ void MetadataSettingsContainer::readFromConfig(KConfigGroup& group)
     {
         rotationBehavior |= RotateByInternalFlag;
     }
+
     if (group.readEntry("Rotate By Metadata Flag", true))
     {
         rotationBehavior |= RotateByMetadataFlag;
     }
+
     if (group.readEntry("Rotate Contents Lossless", true))
     {
         rotationBehavior |= RotateByLosslessRotation;
     }
+
     if (group.readEntry("Rotate Contents Lossy", false))
     {
         rotationBehavior |= RotateByLossyRotation;
@@ -99,6 +106,7 @@ void MetadataSettingsContainer::writeToConfig(KConfigGroup& group) const
 
     group.writeEntry("Save Tags",                   saveTags);
     group.writeEntry("Save Template",               saveTemplate);
+    group.writeEntry("Save FaceTags",               saveFaceTags);
 
     group.writeEntry("Save EXIF Comments",          saveComments);
     group.writeEntry("Save Date Time",              saveDateTime);
@@ -110,6 +118,7 @@ void MetadataSettingsContainer::writeToConfig(KConfigGroup& group) const
     group.writeEntry("Use XMP Sidecar For Reading", useXMPSidecar4Reading);
     group.writeEntry("Metadata Writing Mode",       (int)metadataWritingMode);
     group.writeEntry("Update File Timestamp",       updateFileTimeStamp);
+    group.writeEntry("Rescan File If Modified",     rescanImageIfModified);
 
     group.writeEntry("Rotate By Internal Flag",     bool(rotationBehavior & RotateByInternalFlag));
     group.writeEntry("Rotate By Metadata Flag",     bool(rotationBehavior & RotateByMetadataFlag));
