@@ -7,7 +7,7 @@
  * Description : Settings for Showfoto
  *
  * Copyright (C) 2013-2014 by Mohamed Anwer <mohammed dot ahmed dot anwer at gmail dot com>
- * Copyright (C) 2013-2014 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2013-2015 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -54,6 +54,7 @@ public:
         deleteItem2Trash(true),
         showFormatOverThumbnail(false),
         showCoordinates(false),
+        itemCenter(false),
         showSplash(true),
         reverseSort(false),
         showToolTip(true),
@@ -83,6 +84,7 @@ public:
     static const QString configApplicationStyle;
     static const QString configShowFormatOverThumbnail;
     static const QString configShowCoordinates;
+    static const QString configItemCenter;
     static const QString configShowSplash;
     static const QString configSortOrder;
     static const QString configReverseSort;
@@ -108,6 +110,7 @@ public:
     bool                 deleteItem2Trash;
     bool                 showFormatOverThumbnail;
     bool                 showCoordinates;
+    bool                 itemCenter;
     bool                 showSplash;
     bool                 reverseSort;
 
@@ -151,7 +154,9 @@ const QString ShowfotoSettings::Private::configRightSideBarStyle("Sidebar Title
 const QString ShowfotoSettings::Private::configApplicationStyle("Application Style");
 const QString ShowfotoSettings::Private::configShowFormatOverThumbnail("ShowMimeOverImage");
 const QString ShowfotoSettings::Private::configShowCoordinates("Show Coordinates");
+const QString ShowfotoSettings::Private::configItemCenter("Item To Center");
 const QString ShowfotoSettings::Private::configShowSplash("ShowSplash");
+
 const QString ShowfotoSettings::Private::configSortOrder("SortOrder");
 const QString ShowfotoSettings::Private::configReverseSort("ReverseSort");
 
@@ -219,6 +224,7 @@ void ShowfotoSettings::init()
 
     d->showFormatOverThumbnail = false;
     d->showCoordinates         = false;
+    d->itemCenter              = false;
 
     d->showToolTip             = true;
 
@@ -246,6 +252,7 @@ void ShowfotoSettings::readSettings()
     d->theme                   = group.readEntry(d->configCurrentTheme, Digikam::ThemeManager::instance()->defaultThemeName());
     d->rightSideBarStyle       = group.readEntry(d->configRightSideBarStyle, 0);
     d->applicationStyle        = group.readEntry(d->configApplicationStyle, kapp->style()->objectName());
+    d->itemCenter              = group.readEntry(d->configItemCenter, false);
     d->showSplash              = group.readEntry(d->configShowSplash, true);
     d->sortOrder               = group.readEntry(d->configSortOrder, 0);
     d->reverseSort             = group.readEntry(d->configReverseSort, false);
@@ -306,6 +313,11 @@ QString ShowfotoSettings::getApplicationStyle() const
     return d->applicationStyle;
 }
 
+bool ShowfotoSettings::getItemCenter() const
+{
+    return d->itemCenter;
+}
+
 bool ShowfotoSettings::getShowSplash() const
 {
     return d->showSplash;
@@ -496,6 +508,11 @@ void ShowfotoSettings::setShowCoordinates(bool show)
     d->group.writeEntry(d->configShowCoordinates, show);
 }
 
+void ShowfotoSettings::setItemCenter(bool item)
+{
+    d->group.writeEntry(d->configItemCenter, item);
+}
+
 void ShowfotoSettings::setShowSplash(bool show)
 {
     d->group.writeEntry(d->configShowSplash, show);
