@@ -35,8 +35,8 @@ class DynamicLayout::Private
 {
 public:
 
-    Private(int hSpacing, int vSpacing) :
-        hSpace(hSpacing),
+    Private(int hSpacing, int vSpacing)
+      : hSpace(hSpacing),
         vSpace(vSpacing),
         spaceX(0),
         spaceY(0),
@@ -85,7 +85,7 @@ void DynamicLayout::addItem(QLayoutItem* item)
     d->minItemWidth = 0;
     d->itemList.append(item);
 
-    foreach(QLayoutItem* item, d->itemList)
+    foreach(QLayoutItem* const item, d->itemList)
     {
         QWidget* wid    = item->widget();
         d->spaceX       = qMax<int>(wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton,
@@ -95,9 +95,9 @@ void DynamicLayout::addItem(QLayoutItem* item)
         d->minItemWidth = qMax<int>(wid->sizeHint().width(), d->minItemWidth);
     }
 
-    foreach(QLayoutItem* item, d->itemList)
+    foreach(QLayoutItem* const item, d->itemList)
     {
-        QWidget* wid = item->widget();
+        QWidget* const wid = item->widget();
         wid->setMinimumWidth(d->minItemWidth);
     }
 }
@@ -164,7 +164,8 @@ QSize DynamicLayout::sizeHint() const
 QSize DynamicLayout::minimumSize() const
 {
     QSize size;
-    foreach(QLayoutItem* item, d->itemList)
+
+    foreach(QLayoutItem* const item, d->itemList)
     {
         size = size.expandedTo(item->minimumSize());
     }
@@ -201,14 +202,13 @@ int DynamicLayout::reLayout(const QRect& rect, bool testOnly) const
     }
 
     maxButtonsInRow     = (maxButtonsInRow == 0) ? d->minColumns : maxButtonsInRow;
-    int maxButtonWidth  = d->minItemWidth + (
-                              (effectiveRect.width() - (maxButtonsInRow * buttonWidth)) / maxButtonsInRow);
+    int maxButtonWidth  = d->minItemWidth + ((effectiveRect.width() - (maxButtonsInRow * buttonWidth)) / maxButtonsInRow);
 
     int currentBtnWidth = (maxButtonsInRow >= d->itemList.count()) ? buttonWidth : maxButtonWidth;
 
     // --------------------------------------------------------
 
-    foreach(QLayoutItem* item, d->itemList)
+    foreach(QLayoutItem* const item, d->itemList)
     {
         int nextX = x + currentBtnWidth + d->spaceX;
 
