@@ -6,7 +6,7 @@
  * Date        : 2009-28-04
  * Description : first run assistant dialog
  *
- * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,15 +37,15 @@ class PreviewPage : public AssistantDlgPage
 
 public:
 
-    PreviewPage(KAssistantDialog* dlg);
+    explicit PreviewPage(KAssistantDialog* const dlg);
     ~PreviewPage();
 
     void saveSettings();
 
 private:
 
-    class PreviewPagePriv;
-    PreviewPagePriv* const d;
+    class Private;
+    Private* const d;
 };
 
 }   // namespace Digikam
