@@ -6,7 +6,7 @@
  * Date        : 2006-01-20
  * Description : core image editor GUI implementation private data.
  *
- * Copyright (C) 2006-2014 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2015 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -92,6 +92,7 @@ public:
         zoomMinusAction(0),
         zoomPlusAction(0),
         zoomTo100percents(0),
+        openWithAction(0),
         undoSignalMapper(0),
         redoSignalMapper(0),
         formatMenuActionMapper(0),
@@ -169,6 +170,7 @@ public:
     KAction*                     zoomMinusAction;
     KAction*                     zoomPlusAction;
     KAction*                     zoomTo100percents;
+    KAction*                     openWithAction;
 
     QSignalMapper*               undoSignalMapper;
     QSignalMapper*               redoSignalMapper;
