@@ -40,7 +40,7 @@ class SignalBlocker
 
 public:
 
-    SignalBlocker(QObject* object)
+    explicit SignalBlocker(QObject* const object)
     {
         mObject     = object;
         mWasBlocked = object->blockSignals(true);
