@@ -416,18 +416,18 @@ ImportRotateOverlayButton::ImportRotateOverlayButton(ImportRotateOverlayDirectio
 
 QSize ImportRotateOverlayButton::sizeHint() const
 {
-    return QSize(16, 16);
+    return QSize(32, 32);
 }
 
 QPixmap ImportRotateOverlayButton::icon()
 {
     if (m_direction == ImportRotateOverlayLeft)
     {
-        return KIconLoader::global()->loadIcon("object-rotate-left", KIconLoader::NoGroup, KIconLoader::SizeSmall);
+        return KIconLoader::global()->loadIcon("object-rotate-left", KIconLoader::NoGroup, KIconLoader::SizeMedium);
     }
     else
     {
-        return KIconLoader::global()->loadIcon("object-rotate-right", KIconLoader::NoGroup, KIconLoader::SizeSmall);
+        return KIconLoader::global()->loadIcon("object-rotate-right", KIconLoader::NoGroup, KIconLoader::SizeMedium);
     }
 }
 
@@ -470,9 +470,11 @@ ItemViewHoverButton* ImportRotateOverlay::createButton()
 void ImportRotateOverlay::updateButton(const QModelIndex& index)
 {
     const QRect rect = m_view->visualRect(index);
+    const int size   = qBound(16, rect.width() / 8 - 2, 48);
     const int gap    = 5;
-    const int x      = rect.right() - 2*gap - (isLeft() ? KIconLoader::SizeSmall*5 + 2 : KIconLoader::SizeSmall*4 +2);
+    const int x      = rect.right() - 2*gap - (isLeft() ? size*5 + 2 : size*4 + 2);
     const int y      = rect.top() + gap;
+    button()->resize(size, size);
     button()->move(QPoint(x, y));
 }
 
