@@ -94,6 +94,9 @@ Q_SIGNALS:
     void signalLeftPopupTagsView();
     void signalRightPopupTagsView();
 
+    void signalLeftSlideShowCurrent();
+    void signalRightSlideShowCurrent();
+
     void signalSlideShow();
     void signalDeleteItem(const ImageInfo&);
     void signalEditItem(const ImageInfo&);
