@@ -77,6 +77,7 @@
 #include "iccsettings.h"
 #include "imagewindow.h"
 #include "imagedescedittab.h"
+#include "slideshowbuilder.h"
 #include "slideshow.h"
 #include "setup.h"
 #include "syncjob.h"
@@ -346,9 +347,6 @@ void LightTableWindow::setupStatusBar()
 
 void LightTableWindow::setupConnections()
 {
-    connect(d->statusProgressBar, SIGNAL(signalCancelButtonPressed()),
-            this, SLOT(slotProgressBarCancelButtonPressed()));
-
     connect(ApplicationSettings::instance(), SIGNAL(setupChanged()),
             this, SLOT(slotApplicationSettingsChanged()));
 
@@ -419,7 +417,13 @@ void LightTableWindow::setupConnections()
             this, SLOT(slotDeleteItem(ImageInfo)));
 
     connect(d->previewView, SIGNAL(signalSlideShow()),
-            this, SLOT(slotToggleSlideShow()));
+            this, SLOT(slotSlideShowAll()));
+
+    connect(d->previewView, SIGNAL(signalLeftSlideShowCurrent()),
+            this, SLOT(slotLeftSlideShowManualFromCurrent()));
+
+    connect(d->previewView, SIGNAL(signalRightSlideShowCurrent()),
+            this, SLOT(slotRightSlideShowManualFromCurrent()));
 
     connect(d->previewView, SIGNAL(signalLeftDroppedItems(ImageInfoList)),
             this, SLOT(slotLeftDroppedItems(ImageInfoList)));
@@ -562,7 +566,7 @@ void LightTableWindow::setupActions()
 
     d->slideShowAction = new KAction(KIcon("view-presentation"), i18n("Slideshow"), this);
     d->slideShowAction->setShortcut(KShortcut(Qt::Key_F9));
-    connect(d->slideShowAction, SIGNAL(triggered()), this, SLOT(slotToggleSlideShow()));
+    connect(d->slideShowAction, SIGNAL(triggered()), this, SLOT(slotSlideShowAll()));
     actionCollection()->addAction("lighttable_slideshow", d->slideShowAction);
 
     // Left Panel Zoom Actions
@@ -1410,76 +1414,74 @@ void LightTableWindow::slotEditItem(const ImageInfo& info)
     im->setFocus();
 }
 
-void LightTableWindow::slotToggleSlideShow()
+void LightTableWindow::slotSlideShowAll()
 {
-    SlideShowSettings settings;
-    settings.readFromConfig();
-    slideShow(settings);
+   SlideShowBuilder* const builder = new SlideShowBuilder(d->thumbView->imageInfos());
+
+   d->statusProgressBar->progressBarMode(StatusProgressBar::TextMode,
+                                         i18n("Preparing slideshow. Please wait..."));
+
+   connect(builder, SIGNAL(signalComplete(SlideShowSettings)),
+           this, SLOT(slotSlideShowBuilderComplete(SlideShowSettings)));
+
+   builder->run();
 }
 
-void LightTableWindow::slideShow(SlideShowSettings& settings)
+void LightTableWindow::slotLeftSlideShowManualFromCurrent()
 {
-    if (!d->thumbView->countItems())
-    {
-        return;
-    }
+    slotSlideShowManualFrom(d->previewView->leftImageInfo());
+}
 
-    int              i = 0;
-    d->cancelSlideShow = false;
+void LightTableWindow::slotRightSlideShowManualFromCurrent()
+{
+    slotSlideShowManualFrom(d->previewView->rightImageInfo());
+}
 
-    d->statusProgressBar->progressBarMode(StatusProgressBar::CancelProgressBarMode,
-                                          i18n("Preparing slideshow. Please wait..."));
+void LightTableWindow::slotSlideShowManualFrom(const ImageInfo& info)
+{
+   SlideShowBuilder* const builder = new SlideShowBuilder(d->thumbView->imageInfos());
+   builder->setOverrideStartFrom(info);
+   builder->setAutoPlayEnabled(false);
 
-    ImageInfoList list = d->thumbView->imageInfos();
+   d->statusProgressBar->progressBarMode(StatusProgressBar::TextMode,
+                                         i18n("Preparing slideshow. Please wait..."));
 
-    for (ImageInfoList::const_iterator it = list.constBegin();
-         !d->cancelSlideShow && it != list.constEnd() ; ++it)
-    {
-        SlidePictureInfo pictInfo;
-        pictInfo.comment    = (*it).comment();
-        pictInfo.rating     = (*it).rating();
-        pictInfo.colorLabel = (*it).colorLabel();
-        pictInfo.pickLabel  = (*it).pickLabel();
-        pictInfo.photoInfo  = (*it).photoInfoContainer();
-        settings.pictInfoMap.insert((*it).fileUrl(), pictInfo);
-        settings.fileList.append((*it).fileUrl());
+   connect(builder, SIGNAL(signalComplete(SlideShowSettings)),
+           this, SLOT(slotSlideShowBuilderComplete(SlideShowSettings)));
 
-        d->statusProgressBar->setProgressValue((int)((i++ / (float)list.count()) * 100.0));
-        kapp->processEvents();
-    }
+   builder->run();
+}
+
+void LightTableWindow::slotSlideShowBuilderComplete(const SlideShowSettings& settings)
+{
+    SlideShow* const slide = new SlideShow(settings);
+    TagsActionMngr::defaultManager()->registerActionsToWidget(slide);
 
     d->statusProgressBar->progressBarMode(StatusProgressBar::TextMode, QString());
     slotRefreshStatusBar();
 
-    if (!d->cancelSlideShow)
+    if (settings.imageUrl.isValid())
     {
-        SlideShow* const slide = new SlideShow(settings);
-        TagsActionMngr::defaultManager()->registerActionsToWidget(slide);
-
-        if (settings.startWithCurrent)
-        {
-            slide->setCurrentItem(d->thumbView->currentInfo().fileUrl());
-        }
-
-        connect(slide, SIGNAL(signalRatingChanged(KUrl,int)),
-                d->thumbView, SLOT(slotRatingChanged(KUrl,int)));
-
-        connect(slide, SIGNAL(signalColorLabelChanged(KUrl,int)),
-                d->thumbView, SLOT(slotColorLabelChanged(KUrl,int)));
-
-        connect(slide, SIGNAL(signalPickLabelChanged(KUrl,int)),
-                d->thumbView, SLOT(slotPickLabelChanged(KUrl,int)));
-
-        connect(slide, SIGNAL(signalToggleTag(KUrl,int)),
-                d->thumbView, SLOT(slotToggleTag(KUrl,int)));
-
-        slide->show();
+        slide->setCurrentItem(settings.imageUrl);
+    }
+    else if (settings.startWithCurrent)
+    {
+        slide->setCurrentItem(d->thumbView->currentInfo().fileUrl());
     }
-}
 
-void LightTableWindow::slotProgressBarCancelButtonPressed()
-{
-    d->cancelSlideShow = true;
+    connect(slide, SIGNAL(signalRatingChanged(KUrl,int)),
+            d->thumbView, SLOT(slotRatingChanged(KUrl,int)));
+
+    connect(slide, SIGNAL(signalColorLabelChanged(KUrl,int)),
+            d->thumbView, SLOT(slotColorLabelChanged(KUrl,int)));
+
+    connect(slide, SIGNAL(signalPickLabelChanged(KUrl,int)),
+            d->thumbView, SLOT(slotPickLabelChanged(KUrl,int)));
+
+    connect(slide, SIGNAL(signalToggleTag(KUrl,int)),
+            d->thumbView, SLOT(slotToggleTag(KUrl,int)));
+
+    slide->show();
 }
 
 void LightTableWindow::slotEditKeys()
