@@ -88,7 +88,6 @@ private:
     void setupConnections();
     void setupUserArea();
     void setupStatusBar();
-    void slideShow(SlideShowSettings& settings);
     void readSettings();
     void writeSettings();
 
@@ -120,6 +119,12 @@ private Q_SLOTS:
     void slotLeftZoomFactorChanged(double);
     void slotRightZoomFactorChanged(double);
 
+    void slotLeftSlideShowManualFromCurrent();
+    void slotRightSlideShowManualFromCurrent();
+
+    void slotSlideShowManualFrom(const ImageInfo&);
+    void slotSlideShowBuilderComplete(const SlideShowSettings&);
+
     void slotToggleOnSyncPreview(bool);
     void slotToggleSyncPreview();
     void slotToggleNavigateByPair();
@@ -141,8 +146,7 @@ private Q_SLOTS:
 
     void slotThumbbarDroppedItems(const QList<ImageInfo>&);
 
-    void slotProgressBarCancelButtonPressed();
-    void slotToggleSlideShow();
+    void slotSlideShowAll();
     void slotEditKeys();
     void slotConfToolbars();
     void slotConfNotifications();
