@@ -6,7 +6,7 @@
  * Date        : 2010-03-16
  * Description : 8 to 16 bits color depth converter batch tool.
  *
- * Copyright (C) 2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,7 +37,7 @@ class Convert8to16 : public BatchTool
 
 public:
 
-    Convert8to16(QObject* parent=0);
+    explicit Convert8to16(QObject* const parent = 0);
     ~Convert8to16();
 
     BatchToolSettings defaultSettings()
@@ -45,6 +45,8 @@ public:
         return BatchToolSettings();
     };
 
+    BatchTool* clone(QObject* const parent=0) const { return new Convert8to16(parent); };
+
 private:
 
     bool toolOperations();
@@ -52,7 +54,7 @@ private:
 private Q_SLOTS:
 
     void slotAssignSettings2Widget() {};
-    void slotSettingsChanged() {};
+    void slotSettingsChanged()       {};
 };
 
 }  // namespace Digikam
