@@ -47,6 +47,7 @@
 #include "dimgbuiltinfilter.h"
 #include "dimgloaderobserver.h"
 #include "dimgthreadedfilter.h"
+#include "dmetadata.h"
 #include "filereadwritelock.h"
 #include "batchtoolutils.h"
 #include "jpegsettings.h"
@@ -375,7 +376,10 @@ bool BatchTool::loadToDImg() const
     {
         QImage img;
         bool   ret = KDcraw::loadRawPreview(img, inputUrl().toLocalFile());
+        DMetadata meta(inputUrl().toLocalFile());
+        meta.setImageDimensions(QSize(img.width(), img.height()));
         d->image   = DImg(img);
+        d->image.setMetadata(meta.data());
         return ret;
     }
 
