@@ -160,6 +160,10 @@ public:
      */
     int                          delay;
 
+    /** Whether to enable the auto-move feature.
+     */
+    bool                         autoPlayEnabled;
+
     /** Screen to use in case of multi-monitor computer.
      */
     int                          slideScreen;
@@ -180,6 +184,10 @@ public:
      */
     QMap<KUrl, SlidePictureInfo> pictInfoMap;
 
+    /** URL of the first image to show if requested
+     */
+    KUrl                         imageUrl;
+
 private:
 
     static const QString         configGroupName;
