@@ -42,6 +42,8 @@
     MOVIE2DNG:           https://elphel.svn.sourceforge.net/svnroot/elphel/tools/Movie2DNG
 */
 
+#include "dngwriter_p.h"
+
 // C ansi includes
 
 extern "C"
@@ -70,7 +72,6 @@ extern "C"
 
 // Local includes
 
-#include "dngwriter_p.h"
 #include "dngwriterhost.h"
 #include "kpmetadata.h"
 
@@ -1300,7 +1301,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
         // Metadata makernote cleanup using Exiv2 for some RAW file types
-        // See B.K.O #204437 and #210371, and write XMP Sidecar if necessary
+        // See bug #204437 and #210371, and write XMP Sidecar if necessary
 
         if (meta.load(dngFilePath))
         {
@@ -1363,8 +1364,8 @@ bool DNGWriter::fujiRotate(QByteArray& rawData, KDcrawIface::DcrawInfoContainer&
     QByteArray tmpData(rawData);
     int height             = identify.outputSize.height();
     int width              = identify.outputSize.width();
-    unsigned short* tmp    = (unsigned short*)tmpData.data();
-    unsigned short* output = (unsigned short*)rawData.data();
+    unsigned short* tmp    = reinterpret_cast<unsigned short*>(tmpData.data());
+    unsigned short* output = reinterpret_cast<unsigned short*>(rawData.data());
 
     for (int row=0; row < height; ++row)
     {
