@@ -1,12 +1,13 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2009-12-23
  * Description : Autodetect align_image_stack binary program and version
  *
- * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2012 by Benjamin Girault <benjamin dot girault at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -25,27 +26,35 @@
 
 // Local includes
 
-#include "binaryiface.h"
+#include "kpbinaryiface.h"
 
 using namespace KIPIPlugins;
 
 namespace KIPIExpoBlendingPlugin
 {
 
-class AlignBinary : public BinaryIface
+class AlignBinary : public KPBinaryIface
 {
 
 public:
 
-    AlignBinary();
-    ~AlignBinary();
+    AlignBinary()
+        : KPBinaryIface(QString("align_image_stack"), 
+                        QString("0.8"), 
+                        QString("align_image_stack version "),
+                        1, 
+                        QString("Hugin"), 
+                        QString("http://hugin.sourceforge.net"),
+                        QString("ExpoBlending"), 
+                        QStringList("-h")
+                       )
+        {
+            setup();
+        }
 
-    QString path()           const;
-    QString minimalVersion() const;
-    KUrl    url()            const;
-    QString projectName()    const;
-
-    void    checkSystem();
+    ~AlignBinary()
+    {
+    }
 };
 
 } // namespace KIPIExpoBlendingPlugin
