@@ -1,7 +1,7 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2008-12-26
  * Description : a kipi plugin to import/export images to Facebook web service
@@ -42,10 +42,10 @@ class FbNewAlbum : public KDialog
 
 public:
 
-    FbNewAlbum(QWidget* parent);
+    FbNewAlbum(QWidget* const parent);
     ~FbNewAlbum();
 
-    void getAlbumProperties(FbAlbum &album);
+    void getAlbumProperties(FbAlbum& album);
 
 private:
 
