@@ -688,10 +688,12 @@ bool FlickrTalker::addPhoto(const QString& photoPath, const FPhotoInfo& info,
         }
         else
         {
-            if (rescale && (image.width() > maxDim || image.height() > maxDim))
-                image = image.scaled(maxDim, maxDim, Qt::KeepAspectRatio, Qt::SmoothTransformation);
-
-            image.save(path, "JPEG", imageQuality);
+            if (rescale)
+            {
+                if(image.width() > maxDim || image.height() > maxDim)
+                    image = image.scaled(maxDim, maxDim, Qt::KeepAspectRatio, Qt::SmoothTransformation);   
+                image.save(path, "JPEG", imageQuality);
+            }
         }
 
         // Restore all metadata.
@@ -716,6 +718,16 @@ bool FlickrTalker::addPhoto(const QString& photoPath, const FPhotoInfo& info,
 
         kDebug() << "Resizing and saving to temp file: " << path;
     }
+    
+    QFileInfo tempFileInfo(path);
+    
+    kDebug() << "Image size after resizing (in bytes) is "<< tempFileInfo.size();
+    
+    if(tempFileInfo.size() > (getMaxAllowedFileSize().toLongLong()))
+    {
+        emit signalAddPhotoFailed(i18n("File Size exceeds maximum allowed file size."));
+        return false;
+    }
 
     if (!form.addFile("photo", path))
     {
