@@ -276,12 +276,18 @@ bool PicasawebTalker::addPhoto(const QString& photoPath, GSPhoto& info, const QS
     }
 
     path = KStandardDirs::locateLocal("tmp",QFileInfo(photoPath).baseName().trimmed()+".jpg");
+    
+    int imgQualityToApply = 100;
 
-    if(rescale && (image.width() > maxDim || image.height() > maxDim)){
-        image = image.scaled(maxDim,maxDim,Qt::KeepAspectRatio,Qt::SmoothTransformation);
+    if(rescale)
+    {
+        if(image.width() > maxDim || image.height() > maxDim)
+            image = image.scaled(maxDim,maxDim,Qt::KeepAspectRatio,Qt::SmoothTransformation);
+        
+        imgQualityToApply = imageQuality;
     }
 
-    image.save(path,"JPEG",imageQuality);
+    image.save(path,"JPEG",imgQualityToApply);
 
     KIPIPlugins::KPMetadata meta;
 
@@ -384,12 +390,18 @@ bool PicasawebTalker::updatePhoto(const QString& photoPath, GSPhoto& info,bool r
     }
 
     path = KStandardDirs::locateLocal("tmp",QFileInfo(photoPath).baseName().trimmed()+".jpg");
+    
+    int imgQualityToApply = 100;
 
-    if(rescale && (image.width() > maxDim || image.height() > maxDim)){
-        image = image.scaled(maxDim,maxDim,Qt::KeepAspectRatio,Qt::SmoothTransformation);
+    if(rescale)
+    {
+        if(image.width() > maxDim || image.height() > maxDim)
+            image = image.scaled(maxDim,maxDim,Qt::KeepAspectRatio,Qt::SmoothTransformation);
+        
+        imgQualityToApply = imageQuality;
     }
 
-    image.save(path,"JPEG",imageQuality);
+    image.save(path,"JPEG",imgQualityToApply);
 
     KIPIPlugins::KPMetadata meta;
 
