@@ -7,7 +7,7 @@
  * Description : a kipi plugin to show image using an OpenGL interface.
  *
  * Copyright (C) 2007-2008 by Markus Leuthold <kusi at forum dot titlis dot org>
- * Copyright (C) 2008-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2015 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -464,7 +464,7 @@ void Texture::zoomToOriginal()
     float zoomfactorToOriginal;
     reset();
 
-    if (d->qimage.width()/d->qimage.height() > float(d->display_x)/float(d->display_y))
+    if (float(d->qimage.width())/float(d->qimage.height()) > float(d->display_x)/float(d->display_y))
     {
         //image touches right and left edge of window
         zoomfactorToOriginal = float(d->display_x)/d->qimage.width();
