@@ -77,15 +77,15 @@ public Q_SLOTS:
     void slotBusy(bool val);
 
     void slotButtonClicked(KDialog::ButtonCode button);
-    void slotAddPhotoSuccess(KUrl currentImage, ImgurSuccess success);
-    void slotAddPhotoError(KUrl currentImage, ImgurError error);
+    void slotAddPhotoSuccess(const KUrl& currentImage, const ImgurSuccess& success);
+    void slotAddPhotoError(const KUrl& currentImage, const ImgurError& error);
 //    void slotAuthenticated(bool yes);
     void slotAuthenticated(bool yes, const QString& message = "");
 
 Q_SIGNALS:
 
-    void signalImageUploadSuccess(const KUrl&, ImgurSuccess);
-    void signalImageUploadError(const KUrl&, ImgurError);
+    void signalImageUploadSuccess(const KUrl&, const ImgurSuccess&);
+    void signalImageUploadError(const KUrl&, const ImgurError&);
     void signalImageUploadCompleted();
     void signalContinueUpload(bool yes);
 
@@ -97,8 +97,8 @@ private:
 
 private:
 
-    class ImgurWindowPriv;
-    ImgurWindowPriv* const d;
+    class Private;
+    Private* const d;
 };
 
 } // namespace KIPIImgurExportPlugin
