@@ -6,8 +6,8 @@
  * Date        : 2006-12-05
  * Description : a tool to export image to an Ipod device.
  *
- * Copyright (C) 2006-2008 by Seb Ruiz <ruiz@kde.org>
- * Copyright (C) 2008-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2008 by Seb Ruiz <ruiz at kde dot org>
+ * Copyright (C) 2008-2014 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -61,7 +61,9 @@ Plugin_iPodExport::Plugin_iPodExport(QObject* const parent, const QVariantList&)
 
     kDebug(AREA_CODE_LOADING) << "Plugin_iPodExport plugin loaded" ;
 
+#if !defined(GLIB_VERSION_2_36)
     g_type_init();
+#endif
 
     setUiBaseName("kipiplugin_ipodexportui.rc");
     setupXML();
@@ -84,7 +86,6 @@ void Plugin_iPodExport::setupActions()
     m_actionImageUpload = new KAction(this);
     m_actionImageUpload->setText(i18n("Export to &iPod..."));
     m_actionImageUpload->setIcon(KIcon("multimedia-player-apple-ipod"));
-    m_actionImageUpload->setShortcut(KShortcut(Qt::ALT+Qt::SHIFT+Qt::Key_I));
 
     connect(m_actionImageUpload, SIGNAL(triggered(bool)),
             this, SLOT(slotImageUpload()));
