@@ -839,6 +839,9 @@ void WmWidget::slotLoadImagesDesc(QTreeWidgetItem* item)
     QList<QTreeWidgetItem*> selectedItems = d->imgList->listView()->selectedItems();
     KPImagesListViewItem* const l_item    = dynamic_cast<KPImagesListViewItem*>(item);
 
+    if (!l_item)
+        return;
+
     QMap<QString, QString> imageMetaData;
 
     if (!d->imagesDescInfo.contains(l_item->url().path())) 
@@ -885,7 +888,9 @@ void WmWidget::slotRestoreExtension()
     for (int i = 0; i < selectedItems.size(); ++i)
     {
         KPImagesListViewItem* const l_item = dynamic_cast<KPImagesListViewItem*>(selectedItems.at(i));
-        urls.append(l_item->url());
+
+        if (l_item)
+            urls.append(l_item->url());
     }
 
     for (int i = 0; i < urls.size(); ++i)
@@ -897,7 +902,7 @@ void WmWidget::slotRestoreExtension()
         currentExtension  = imageTitle.split('.').last();
         originalExtension = urls.at(i).path().split('.').last();
 
-        if(QString::compare(currentExtension, originalExtension, Qt::CaseInsensitive) != 0)
+        if (QString::compare(currentExtension, originalExtension, Qt::CaseInsensitive) != 0)
         {
             imageTitle.append(".").append(originalExtension);
             d->titleEdit->setText(imageTitle);
@@ -927,7 +932,9 @@ void WmWidget::slotApplyTitle()
     for (int i = 0; i < selectedItems.size(); ++i)
     {
         KPImagesListViewItem* const l_item = dynamic_cast<KPImagesListViewItem*>(selectedItems.at(i));
-        urls.append(l_item->url());
+
+        if (l_item)
+            urls.append(l_item->url());
     }
 
     for (int i = 0; i < urls.size(); ++i)
@@ -964,7 +971,9 @@ void WmWidget::slotApplyDate()
     for (int i = 0; i < selectedItems.size(); ++i)
     {
         KPImagesListViewItem* const l_item = dynamic_cast<KPImagesListViewItem*>(selectedItems.at(i));
-        urls.append(l_item->url());
+
+        if (l_item)
+            urls.append(l_item->url());
     }
 
     for (int i = 0; i < urls.size(); ++i)
@@ -984,7 +993,9 @@ void WmWidget::slotApplyCategories()
     for (int i = 0; i < selectedItems.size(); ++i)
     {
         KPImagesListViewItem* const l_item = dynamic_cast<KPImagesListViewItem*>(selectedItems.at(i));
-        urls.append(l_item->url());
+
+        if (l_item)
+            urls.append(l_item->url());
     }
 
     for (int i = 0; i < urls.size(); ++i)
@@ -1004,7 +1015,9 @@ void WmWidget::slotApplyDescription()
     for (int i = 0; i < selectedItems.size(); ++i)
     {
         KPImagesListViewItem* const l_item = dynamic_cast<KPImagesListViewItem*>(selectedItems.at(i));
-        urls.append(l_item->url());
+
+        if (l_item)
+            urls.append(l_item->url());
     }
 
     for (int i = 0; i < urls.size(); ++i)
@@ -1025,7 +1038,9 @@ void WmWidget::slotApplyLatitude()
     for (int i = 0; i < selectedItems.size(); ++i)
     {
         KPImagesListViewItem* const l_item = dynamic_cast<KPImagesListViewItem*>(selectedItems.at(i));
-        urls.append(l_item->url());
+
+        if (l_item)
+            urls.append(l_item->url());
     }
 
     for (int i = 0; i < urls.size(); ++i)
@@ -1045,7 +1060,9 @@ void WmWidget::slotApplyLongitude()
     for (int i = 0; i < selectedItems.size(); ++i)
     {
         KPImagesListViewItem* const l_item = dynamic_cast<KPImagesListViewItem*>(selectedItems.at(i));
-        urls.append(l_item->url());
+
+        if (l_item)
+            urls.append(l_item->url());
     }
 
     for (int i = 0; i < urls.size(); ++i)
