@@ -8,7 +8,7 @@
  * Acknowledge : based on the expoblending plugin
  *
  * Copyright (C) 2011-2012 by Benjamin Girault <benjamin dot girault at gmail dot com>
- * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2015 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -55,17 +55,19 @@ public:
 private Q_SLOTS:
 
     void slotToggleGPano(int state);
-//     void slotShowFileFormat(int state);
     void slotChangeFileFormat(QAbstractButton* button);
 
+    // TODO HDR
+//     void slotShowFileFormat(int state);
+
 Q_SIGNALS:
 
     void signalIntroPageIsValid(bool);
 
 private:
 
-    struct IntroPagePriv;
-    IntroPagePriv* const d;
+    struct Private;
+    Private* const d;
 };
 
 }   // namespace KIPIPanoramaPlugin
