@@ -92,15 +92,11 @@ void CompileMKStepTask::run()
     {
         errString = getProcessError(*process);
         successFlag = false;
+        return;
     }
-    else
-    {
-        successFlag = true;
-    }
-
-    delete process;
-    process = 0;
+    kDebug() << "make job's output (" << mkFile << "):" << endl << process->readAll();
 
+    successFlag = true;
     return;
 }
 
